==> openshift-model-hive-5.12.3-sources.jar: io/fabric8/openshift/api/model/hive/v1/MachinePoolConditionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachinePoolConditionBuilder extends io.fabric8.openshift.api.model.hive.v1.MachinePoolConditionFluentImpl<io.fabric8.openshift.api.model.hive.v1.MachinePoolConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.MachinePoolCondition,io.fabric8.openshift.api.model.hive.v1.MachinePoolConditionBuilder>{
  public MachinePoolConditionBuilder() {
    this(false);
  }
  public MachinePoolConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new MachinePoolCondition(), validationEnabled);
  }
  public MachinePoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.MachinePoolConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.MachinePoolConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachinePoolCondition(), validationEnabled);
  }
  public MachinePoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.MachinePoolConditionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.MachinePoolCondition instance) {
    this(fluent, instance, false);
  }
  public MachinePoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.MachinePoolConditionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.MachinePoolCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.MachinePoolCondition instance) {
    this(instance,false);
  }
  public MachinePoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.MachinePoolCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.MachinePoolConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.MachinePoolCondition build() {
    MachinePoolCondition buildable = new MachinePoolCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachinePoolConditionBuilder that = (MachinePoolConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.4.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/MachinePoolConditionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachinePoolConditionBuilder extends MachinePoolConditionFluentImpl<MachinePoolConditionBuilder> implements VisitableBuilder<MachinePoolCondition,MachinePoolConditionBuilder>{
  public MachinePoolConditionBuilder() {
    this(false);
  }
  public MachinePoolConditionBuilder(Boolean validationEnabled) {
    this(new MachinePoolCondition(), validationEnabled);
  }
  public MachinePoolConditionBuilder(MachinePoolConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolConditionBuilder(MachinePoolConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachinePoolCondition(), validationEnabled);
  }
  public MachinePoolConditionBuilder(MachinePoolConditionFluent<?> fluent,MachinePoolCondition instance) {
    this(fluent, instance, false);
  }
  public MachinePoolConditionBuilder(MachinePoolConditionFluent<?> fluent,MachinePoolCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolConditionBuilder(MachinePoolCondition instance) {
    this(instance,false);
  }
  public MachinePoolConditionBuilder(MachinePoolCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachinePoolConditionFluent<?> fluent;
  Boolean validationEnabled;
  public MachinePoolCondition build() {
    MachinePoolCondition buildable = new MachinePoolCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
